@@ -202,7 +202,7 @@ updatePoles = function(...) {
     return(cnt)
   }
   
-  file.path(
+  nc4 = file.path(
     serverPath(
       "poles"
       , ip = nfo[["gimms.poles.server"]]
@@ -213,6 +213,8 @@ updatePoles = function(...) {
       , value = TRUE
     )
   )
+  
+  sort(nc4)
 }
 
 
@@ -291,13 +293,15 @@ getPolesFTPInfo = function(
         , value = TRUE
       )
       
-      regmatches(
+      hits = regmatches(
         txt
         , regexpr(
           y
           , text = txt
         )
       )
+      
+      unique(hits)
     }
     # ftp components
     , x = list(
@@ -307,10 +311,7 @@ getPolesFTPInfo = function(
     )
     # regex
     , y = list(
-      paste(
-        rep("\\d{2,3}", 4)
-        , collapse = "."
-      )
+      "ftp\\d?[a-z.]+\\.cn"
       , "download_\\d+"
       , "\\d+"
     )
